@@ -32,64 +32,12 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 
-#include <gst/gst.h>
 #include <gio/gio.h>
 #include <gtest/gtest.h>
 
 using namespace std;
 using namespace mediascanner;
 
-namespace {
-
-bool supports_decoder(const std::string& format)
-{
-    typedef std::unique_ptr<GstCaps, decltype(&gst_caps_unref)> CapsPtr;
-    static std::vector<CapsPtr> formats;
-
-    if (formats.empty())
-    {
-        std::unique_ptr<GList, decltype(&gst_plugin_feature_list_free)> decoders(
-            gst_element_factory_list_get_elements(GST_ELEMENT_FACTORY_TYPE_DECODER, GST_RANK_NONE),
-            gst_plugin_feature_list_free);
-        for (const GList* l = decoders.get(); l != nullptr; l = l->next)
-        {
-            const auto factory = static_cast<GstElementFactory*>(l->data);
-
-            const GList* templates = gst_element_factory_get_static_pad_templates(factory);
-            for (const GList* l = templates; l != nullptr; l = l->next)
-            {
-                const auto t = static_cast<GstStaticPadTemplate*>(l->data);
-                if (t->direction != GST_PAD_SINK)
-                {
-                    continue;
-                }
-                CapsPtr caps(gst_static_caps_get(&t->static_caps),
-                             gst_caps_unref);
-                if (gst_caps_is_any(caps.get())) {
-                    continue;
-                }
-                formats.emplace_back(std::move(caps));
-            }
-        }
-    }
-
-    char *end = nullptr;
-    GstStructure *structure = gst_structure_from_string(format.c_str(), &end);
-    assert(structure != nullptr);
-    assert(end == format.c_str() + format.size());
-    // GstCaps adopts the GstStructure
-    CapsPtr caps(gst_caps_new_full(structure, nullptr), gst_caps_unref);
-
-    for (const auto &other : formats) {
-        if (gst_caps_is_always_compatible(caps.get(), other.get())) {
-            return true;
-        }
-    }
-    return false;
-}
-
-}
-
 class MetadataExtractorTest : public ::testing::Test {
 protected:
     virtual void SetUp() override {
@@ -187,10 +135,6 @@ TEST_F(MetadataExtractorTest, extract) {
 }
 
 TEST_F(MetadataExtractorTest, extract_mp3) {
-    if (!supports_decoder("audio/mpeg, mpegversion=(int)1, layer=(int)3")) {
-        printf("MP3 codec not supported\n");
-        return;
-    }
     MetadataExtractor e(session_bus());
     string testfile = SOURCE_DIR "/media/testfile.mp3";
     MediaFile file = e.extract(e.detect(testfile));
@@ -209,11 +153,6 @@ TEST_F(MetadataExtractorTest, extract_mp3) {
 }
 
 TEST_F(MetadataExtractorTest, extract_m4a) {
-    if (!supports_decoder("audio/mpeg, mpegversion=(int)4, stream-format=(string)raw")) {
-        printf("M4A codec not supported\n");
-        return;
-    }
-
     MetadataExtractor e(session_bus());
     string testfile = SOURCE_DIR "/media/testfile.m4a";
     MediaFile file = e.extract(e.detect(testfile));
@@ -291,10 +230,6 @@ TEST_F(MetadataExtractorTest, extract_bad_date) {
 }
 
 TEST_F(MetadataExtractorTest, extract_mp3_bad_date) {
-    if (!supports_decoder("audio/mpeg, mpegversion=(int)1, layer=(int)3")) {
-        printf("MP3 codec not supported\n");
-        return;
-    }
     MetadataExtractor e(session_bus());
     string testfile = SOURCE_DIR "/media/baddate.mp3";
     MediaFile file = e.extract(e.detect(testfile));
@@ -371,7 +306,6 @@ TEST_F(MetadataExtractorTest, crash_recovery) {
 }
 
 int main(int argc, char **argv) {
-    gst_init(&argc, &argv);
     ::testing::InitGoogleTest(&argc, argv);
     return RUN_ALL_TESTS();
 }
